@@ -21,6 +21,8 @@ classes that hold units of comma-separated values (.csv) files (csvunit)
 or entire files (csvfile) for use with localisation.
 """
 
+from __future__ import annotations
+
 import csv
 
 from translate.storage import base
@@ -87,12 +89,12 @@ class csvunit(base.TranslationUnit):
             return result
         if origin == "translator":
             return self.translator_comments
-        if origin in ("programmer", "developer", "source code"):
+        if origin in {"programmer", "developer", "source code"}:
             return self.developer_comments
         raise ValueError("Comment type not valid")
 
     def addnote(self, text, origin=None, position="append"):
-        if origin in ("programmer", "developer", "source code"):
+        if origin in {"programmer", "developer", "source code"}:
             if position == "append" and self.developer_comments:
                 self.developer_comments += "\n" + text
             elif position == "prepend" and self.developer_comments:
@@ -110,9 +112,7 @@ class csvunit(base.TranslationUnit):
         self.translator_comments = ""
 
     def isfuzzy(self):
-        if self.fuzzy.lower() in ("1", "x", "true", "yes", "fuzzy"):
-            return True
-        return False
+        return self.fuzzy.lower() in {"1", "x", "true", "yes", "fuzzy"}
 
     def markfuzzy(self, value=True):
         if value:
@@ -291,7 +291,9 @@ class csvfile(base.TranslationStore):
             inputfile.close()
             self.parse(csvsrc)
 
-    def parse(self, csvsrc, sample_length=1024):
+    def parse(
+        self, csvsrc, sample_length: int | None = 1024, *, dialect: None | str = None
+    ):
         if self._encoding == "auto":
             text, encoding = self.detect_encoding(
                 csvsrc, default_encodings=["utf-8", "utf-16"]
@@ -305,14 +307,17 @@ class csvfile(base.TranslationStore):
         sniffer = csv.Sniffer()
         sample = text[:sample_length] if sample_length else text
 
-        try:
-            self.dialect = sniffer.sniff(sample)
-            if self.dialect.quoting == csv.QUOTE_MINIMAL:
-                # HACKISH: most probably a default, not real detection
-                self.dialect.quoting = csv.QUOTE_ALL
-                self.dialect.doublequote = True
-        except csv.Error:
-            self.dialect = "default"
+        if dialect is not None:
+            self.dialect = dialect
+        else:
+            try:
+                self.dialect = sniffer.sniff(sample)
+                if self.dialect.quoting == csv.QUOTE_MINIMAL:
+                    # HACKISH: most probably a default, not real detection
+                    self.dialect.quoting = csv.QUOTE_ALL
+                    self.dialect.doublequote = True
+            except csv.Error:
+                self.dialect = "default"
 
         inputfile = csv.StringIO(text)
         try:
